import { Task, RobotAction } from '../types/task';
import { v4 as uuidv4 } from 'uuid';

export const LOCATIONS = Array.from({ length: 100 }, (_, i) => ({
  label: `AP-${i + 1}`,
  value: `AP-${i + 1}`,
}));

export const ROBOT_ACTIONS: { label: string; value: RobotAction }[] = [
  { label: '运输', value: 'TRANSPORT' },
  { label: '取货', value: 'PICKUP' },
  { label: '卸货', value: 'DROPOFF' },
  { label: '等待', value: 'WAIT' },
  { label: '充电', value: 'CHARGE' },
  { label: '清洁', value: 'CLEAN' },
];

export const LOCATIONS_BAYS = Array.from({ length: 100 }, (_, i) => ({
  label: `AS2_2_${String(i + 1).padStart(3, '0')}`,
  value: `AS2_2_${String(i + 1).padStart(3, '0')}`,
}));

export const PAYLOADS = [
  { label: '满料架-A1', value: '满料架-A1' },
  { label: '空料架-B2', value: '空料架-B2' },
  { label: '空料架-C3', value: '空料架-C3' },
  { label: '空车', value: '空车' },
];

const getRandomElement = <T>(arr: T[]): T =>
  arr[Math.floor(Math.random() * arr.length)];

export const MOCK_TASKS: Task[] = Array.from({ length: 15 }, (_, i) => {
  const startLocation = getRandomElement(LOCATIONS);
  const endLocation = getRandomElement(
    LOCATIONS.filter(l => l.value !== startLocation.value),
  );
  const robotAction = getRandomElement(ROBOT_ACTIONS);
  const payload = getRandomElement(PAYLOADS);
  const statusOptions: Task['status'][] = [
    'IDLE',
    'RUNNING',
    'COMPLETED',
    'ERROR',
  ];
  const status = getRandomElement(statusOptions);

  return {
    id: uuidv4(),
    name: `任务 ${i + 1}: 从 ${startLocation.label} 到 ${endLocation.label}`,
    status: status,
    createdAt: new Date(
      new Date().getTime() - Math.random() * 1000 * 60 * 60 * 24,
    ).toISOString(),
    parameters: {
      startLocation: startLocation.value,
      endLocation: endLocation.value,
      robotAction: robotAction.value,
      payload: payload.value,
      locationBay: '', // 库位初始值为空
    },
  };
});
